@@ -8,7 +8,7 @@ if not os.environ.get('DESTDIR'):
   libdir = sys.argv[1]
 
   print('Byte-compiling python modules...')
-  subprocess.call(['python3', '-m', 'compileall', '-f', '-q', libdir])
+  subprocess.check_call(['python3', '-m', 'compileall', '-f', '-q', libdir])
 
   print('Byte-compiling python modules (optimized versions) ...')
-  subprocess.call(['python3', '-O', '-m', 'compileall', '-f', '-q', libdir])
+  subprocess.check_call(['python3', '-O', '-m', 'compileall', '-f', '-q', libdir])
